########
InsarViz
########

InsarViz is a project dedicated to the visualisation of InSar data. 

The ts_viz app is designed to visualize and interactively analyze time-series (datacubes) from InSAR data processing chains.

The full documentation is available here: 

https://deformvis.gricad-pages.univ-grenoble-alpes.fr/insarviz

Installation
************

Detailed installation instructions can be found `here <doc/installation.rst>`_

How to cite
***********

If you use InsarViz for your project, please consider citing `this paper <https://doi.org/10.21105/joss.06440>`_

Contact
*******
If you need help or have ideas for further developments, you can contact:
insarviz-sos@univ-grenoble-alpes.fr

